@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 import pydov.util.caching
 from pydov.util.hooks import Hooks, SimpleStatusHook
-from pydov.util.net import SessionFactory
+from pydov.util.net import SessionFactory, proxy_autoconfiguration
 
 __author__ = """DOV-Vlaanderen"""
-__version__ = '2.1.0'
+__version__ = '2.2.2'
 
 cache = pydov.util.caching.GzipTextFileCache()
 
@@ -12,6 +12,9 @@ hooks = Hooks(
     (SimpleStatusHook(),)
 )
 
+# try proxy autoconfiguration via PAC
+proxy_autoconfiguration()
+
 # Package wide requests session object. This increases performance as using a
 # session object allows connection pooling and TCP connection reuse.
 session = SessionFactory.get_session()
