@@ -3,6 +3,7 @@
 
 import datetime
 from distutils.util import strtobool
+import warnings
 
 import owslib
 import pandas as pd
@@ -10,6 +11,7 @@ from owslib.etree import etree
 from owslib.feature import get_schema
 from owslib.fes import FilterRequest
 from owslib.wfs import WebFeatureService
+import numpy as np
 
 import pydov
 from pydov.types.fields import _WfsInjectedField
@@ -17,7 +19,7 @@ from pydov.util import owsutil
 from pydov.util.dovutil import build_dov_url, get_xsd_schema
 from pydov.util.errors import (FeatureOverflowError, InvalidFieldError,
                                InvalidSearchParameterError, LayerNotFoundError,
-                               WfsGetFeatureError)
+                               WfsGetFeatureError, DataParseWarning)
 from pydov.util.hooks import HookRunner
 
 
@@ -65,7 +67,7 @@ class AbstractCommon(object):
             def typeconvert(x):
                 if x.endswith('Z'):
                     return datetime.datetime.strptime(
-                        x, '%Y-%m-%dT%H:%M:%SZ').date() \
+                        x, '%Y-%m-%dT%H:%M:%SZ') \
                         + datetime.timedelta(days=1)
                 else:
                     return datetime.datetime.strptime(
@@ -77,7 +79,14 @@ class AbstractCommon(object):
             def typeconvert(x):
                 return x
 
-        return typeconvert(text)
+        try:
+            return typeconvert(text)
+        except ValueError as e:
+            warnings.warn(
+                f"Failed to convert data to correct datatype: {e}. Resulting "
+                "dataframe will be incomplete.",
+                DataParseWarning)
+            return np.nan
 
 
 class AbstractSearch(AbstractCommon):
