@@ -2,10 +2,9 @@
 """Module implementing a simple hooks system to allow late-binding actions to
 PyDOV events."""
 
-from multiprocessing import Lock
-
 import sys
 import time
+from multiprocessing import Lock
 
 import pydov
 
@@ -13,6 +12,7 @@ import pydov
 class Hooks(list):
     """Runtime representation of registered pydov hooks, i.e. a list of
     instances of AbstractReadHook and/or AbstractInjectHook."""
+
     def get_read_hooks(self):
         """Get the registered read hooks (i.e. hooks that are subclasses of
         AbstractReadHook), in the order they are defined in the list.
@@ -157,10 +157,33 @@ class HookRunner(object):
         ----------
         pkey_object : str
             Permanent key of the requested object.
-
         """
         HookRunner.__execute_read('xml_cache_hit', [pkey_object])
 
+    @staticmethod
+    def execute_xml_stale_hit(pkey_object):
+        """Execute the xml_stale_hit method for all registered hooks.
+
+        Parameters
+        ----------
+        pkey_object : str
+            Permanent key of the requested object.
+
+        """
+        HookRunner.__execute_read('xml_stale_hit', [pkey_object])
+
+    @staticmethod
+    def execute_xml_fetch_error(pkey_object):
+        """Execute the xml_fetch_error method for all registered hooks.
+
+        Parameters
+        ----------
+        pkey_object : str
+            Permanent key of the requested object.
+
+        """
+        HookRunner.__execute_read('xml_fetch_error', [pkey_object])
+
     @staticmethod
     def execute_xml_downloaded(pkey_object):
         """Execute the xml_downloaded method for all registered hooks.
@@ -243,6 +266,7 @@ class AbstractReadHook(object):
     they need.
 
     """
+
     def meta_received(self, url, response):
         """Called when a response for a metadata requests is received.
 
@@ -337,6 +361,40 @@ class AbstractReadHook(object):
         """
         pass
 
+    def xml_stale_hit(self, pkey_object):
+        """Called when the XML document of an object failed to be retrieved
+        from the DOV service and a stale version has been returned from the
+        cache.
+
+        Because of parallel processing, this method will be called
+        simultaneously from multiple threads. Make sure your implementation is
+        threadsafe or uses locking.
+
+        Parameters
+        ----------
+        pkey_object : str
+            Permanent key of the requested object.
+
+        """
+        pass
+
+    def xml_fetch_error(self, pkey_object):
+        """Called when the XML document of an object failed to be retrieved
+        from the DOV service and no stale version could be returned from the
+        cache.
+
+        Because of parallel processing, this method will be called
+        simultaneously from multiple threads. Make sure your implementation is
+        threadsafe or uses locking.
+
+        Parameters
+        ----------
+        pkey_object : str
+            Permanent key of the requested object.
+
+        """
+        pass
+
     def xml_downloaded(self, pkey_object):
         """Called when the XML document of an object is downloaded from the
         DOV services.
@@ -370,6 +428,7 @@ class AbstractInjectHook(object):
     they need.
 
     """
+
     def inject_meta_response(self, url):
         """Inject a response for a metadata request.
 
@@ -455,6 +514,7 @@ class AbstractInjectHook(object):
 
 class SimpleStatusHook(AbstractReadHook):
     """Simple hook implementation to print progress to stdout."""
+
     def __init__(self):
         """Initialisation.
 
@@ -485,9 +545,9 @@ class SimpleStatusHook(AbstractReadHook):
             sys.stdout.flush()
         elif self.prog_counter % 50 == 0:
             time_elapsed = time.time() - self.init_time
-            time_per_item = time_elapsed/self.prog_counter
-            remaining_mins = int((time_per_item*(
-                self.result_count-self.prog_counter))/60)
+            time_per_item = time_elapsed / self.prog_counter
+            remaining_mins = int((time_per_item * (
+                self.result_count - self.prog_counter)) / 60)
             if remaining_mins > 1 and remaining_mins != \
                     self.previous_remaining:
                 remaining = " ({:d} min. left)".format(remaining_mins)
@@ -545,6 +605,32 @@ class SimpleStatusHook(AbstractReadHook):
         with self.lock:
             self._write_progress('c')
 
+    def xml_stale_hit(self, pkey_object):
+        """When a stale XML document is retrieved from the cache, print 'S' to
+        the progress output.
+
+        Parameters
+        ----------
+        pkey_object : str
+            Permanent key of the requested object.
+
+        """
+        with self.lock:
+            self._write_progress('S')
+
+    def xml_fetch_error(self, pkey_object):
+        """When an XML document failed to be fetched from DOV, print 'E' to
+        the progress output.
+
+        Parameters
+        ----------
+        pkey_object : str
+            Permanent key of the requested object.
+
+        """
+        with self.lock:
+            self._write_progress('E')
+
     def xml_downloaded(self, pkey_object):
         """When an XML document is downloaded from the DOV services,
         print '.' to the progress output.
