@@ -4,9 +4,11 @@ import numpy as np
 import pytest
 
 from pydov.search.bodemlocatie import BodemlocatieSearch
+from pydov.search.bodemdiepteinterval import BodemdiepteintervalSearch
 from pydov.search.bodemmonster import BodemmonsterSearch
 from pydov.search.bodemobservatie import BodemobservatieSearch
 from pydov.search.bodemsite import BodemsiteSearch
+from pydov.search.bodemclassificatie import BodemclassificatieSearch
 from pydov.search.boring import BoringSearch
 from pydov.search.grondmonster import GrondmonsterSearch
 from pydov.search.grondwaterfilter import GrondwaterFilterSearch
@@ -24,8 +26,10 @@ from tests.abstract import ServiceCheck
 
 search_objects = [BodemsiteSearch(),
                   BodemlocatieSearch(),
+                  BodemdiepteintervalSearch(),
                   BodemobservatieSearch(),
                   BodemmonsterSearch(),
+                  BodemclassificatieSearch(),
                   BoringSearch(),
                   SonderingSearch(),
                   GrondwaterFilterSearch(),
