@@ -4,8 +4,10 @@ import pytest
 
 from pydov.types.bodemsite import Bodemsite
 from pydov.types.bodemlocatie import Bodemlocatie
+from pydov.types.bodemdiepteinterval import Bodemdiepteinterval
 from pydov.types.bodemobservatie import Bodemobservatie
 from pydov.types.bodemmonster import Bodemmonster
+from pydov.types.bodemclassificatie import Bodemclassificatie
 from pydov.types.boring import Boring
 from pydov.types.fields import XmlField
 from pydov.types.grondwaterfilter import GrondwaterFilter
@@ -26,8 +28,10 @@ from pydov.types.sondering import Sondering
 
 type_objects = [Bodemsite,
                 Bodemlocatie,
+                Bodemdiepteinterval,
                 Bodemobservatie,
                 Bodemmonster,
+                Bodemclassificatie,
                 Boring,
                 Sondering,
                 GrondwaterFilter,
